@@ -3,6 +3,7 @@ package shared
 import (
 	"fmt"
 	"net/url"
+	"slices"
 	"strings"
 
 	"github.com/cli/cli/v2/api"
@@ -63,7 +64,10 @@ func AddMetadataToIssueParams(client *api.Client, baseRepo ghrepo.Interface, par
 	// Retrieve minimal information needed to resolve metadata if this was not previously cached from additional metadata survey.
 	if tb.MetadataResult == nil {
 		input := api.RepoMetadataInput{
-			Reviewers:      len(tb.Reviewers) > 0,
+			Reviewers: len(tb.Reviewers) > 0,
+			TeamReviewers: len(tb.Reviewers) > 0 && slices.ContainsFunc(tb.Reviewers, func(r string) bool {
+				return strings.ContainsRune(r, '/')
+			}),
 			Assignees:      len(tb.Assignees) > 0,
 			ActorAssignees: tb.ActorAssignees,
 			Labels:         len(tb.Labels) > 0,
@@ -182,20 +186,20 @@ func (opts *FilterOptions) IsDefault() bool {
 	return true
 }
 
-func ListURLWithQuery(listURL string, options FilterOptions) (string, error) {
+func ListURLWithQuery(listURL string, options FilterOptions, advancedIssueSearchSyntax bool) (string, error) {
 	u, err := url.Parse(listURL)
 	if err != nil {
 		return "", err
 	}
 
 	params := u.Query()
-	params.Set("q", SearchQueryBuild(options))
+	params.Set("q", SearchQueryBuild(options, advancedIssueSearchSyntax))
 	u.RawQuery = params.Encode()
 
 	return u.String(), nil
 }
 
-func SearchQueryBuild(options FilterOptions) string {
+func SearchQueryBuild(options FilterOptions, advancedIssueSearchSyntax bool) string {
 	var is, state string
 	switch options.State {
 	case "open", "closed":
@@ -203,7 +207,7 @@ func SearchQueryBuild(options FilterOptions) string {
 	case "merged":
 		is = "merged"
 	}
-	q := search.Query{
+	query := search.Query{
 		Qualifiers: search.Qualifiers{
 			Assignee:  options.Assignee,
 			Author:    options.Author,
@@ -218,11 +222,13 @@ func SearchQueryBuild(options FilterOptions) string {
 			Is:        []string{is},
 			Type:      options.Entity,
 		},
+		ImmutableKeywords: options.Search,
 	}
-	if options.Search != "" {
-		return fmt.Sprintf("%s %s", options.Search, q.String())
+
+	if !advancedIssueSearchSyntax {
+		return query.StandardSearchString()
 	}
-	return q.String()
+	return query.AdvancedIssueSearchString()
 }
 
 func QueryHasStateClause(searchQuery string) bool {
@@ -289,11 +295,24 @@ func (r *MeReplacer) ReplaceSlice(handles []string) ([]string, error) {
 // Login is generally needed for API calls; name is used when launching web browser.
 type CopilotReplacer struct {
 	returnLogin bool
+	// copilotLogin is the login to use when replacing @copilot.
+	// Different Copilot features use different bot logins.
+	copilotLogin string
 }
 
+// NewCopilotReplacer creates a replacer for assignee @copilot references.
 func NewCopilotReplacer(returnLogin bool) *CopilotReplacer {
 	return &CopilotReplacer{
-		returnLogin: returnLogin,
+		returnLogin:  returnLogin,
+		copilotLogin: api.CopilotAssigneeLogin,
+	}
+}
+
+// NewCopilotReviewerReplacer creates a replacer for reviewer @copilot references.
+func NewCopilotReviewerReplacer() *CopilotReplacer {
+	return &CopilotReplacer{
+		returnLogin:  true,
+		copilotLogin: api.CopilotReviewerLogin,
 	}
 }
 
@@ -302,7 +321,7 @@ func (r *CopilotReplacer) replace(handle string) string {
 		return handle
 	}
 	if r.returnLogin {
-		return api.CopilotActorLogin
+		return r.copilotLogin
 	}
 	return api.CopilotActorName
 }
